@@ -22,7 +22,7 @@
 #include "prcvar.h"
 #include "prlog.h" /* for PR_ASSERT */
 #include "fe.h"
-#include <sasl.h>
+#include <sasl/sasl.h>
 #if defined(LINUX)
 #include <netinet/tcp.h> /* for TCP_CORK */
 #endif
@@ -244,6 +244,28 @@ connection_cleanup(Connection *conn)
     conn->c_ns_close_jobs = 0;
 }
 
+static char *
+get_ip_str(struct sockaddr *addr, char *str)
+{
+    switch(addr->sa_family) {
+        case AF_INET:
+            if (sizeof(str) < INET_ADDRSTRLEN) {
+                break;
+            }
+            inet_ntop(AF_INET, &(((struct sockaddr_in *)addr)->sin_addr), str, INET_ADDRSTRLEN);
+            break;
+
+        case AF_INET6:
+            if (sizeof(str) < INET6_ADDRSTRLEN) {
+                break;
+            }
+            inet_ntop(AF_INET6, &(((struct sockaddr_in6 *)addr)->sin6_addr), str, INET6_ADDRSTRLEN);
+            break;
+    }
+
+    return str;
+}
+
 /*
  * Callers of connection_reset() must hold the conn->c_mutex lock.
  */
@@ -252,7 +274,8 @@ connection_reset(Connection *conn, int ns, PRNetAddr *from, int fromLen __attrib
 {
     char *pTmp = is_SSL ? "SSL " : "";
     char *str_ip = NULL, *str_destip;
-    char buf_ip[256], buf_destip[256];
+    char buf_ip[INET6_ADDRSTRLEN + 1] = {0};
+    char buf_destip[INET6_ADDRSTRLEN + 1] = {0};
     char *str_unknown = "unknown";
     int in_referral_mode = config_check_referral_mode();
 
@@ -288,10 +311,10 @@ connection_reset(Connection *conn, int ns, PRNetAddr *from, int fromLen __attrib
                 (from->ipv6.ip.pr_s6_addr32[1] != 0) ||
                 (from->ipv6.ip.pr_s6_addr32[2] != 0) ||
                 (from->ipv6.ip.pr_s6_addr32[3] != 0)) ||
-               ((conn->c_prfd != NULL) && (PR_GetPeerName(conn->c_prfd, from) == 0))) {
+               ((conn->c_prfd != NULL) && (PR_GetPeerName(conn->c_prfd, from) == 0)))
+    {
         conn->cin_addr = (PRNetAddr *)slapi_ch_malloc(sizeof(PRNetAddr));
         memcpy(conn->cin_addr, from, sizeof(PRNetAddr));
-
         if (PR_IsNetAddrType(conn->cin_addr, PR_IpAddrV4Mapped)) {
             PRNetAddr v4addr = {{0}};
             v4addr.inet.family = PR_AF_INET;
@@ -305,7 +328,7 @@ connection_reset(Connection *conn, int ns, PRNetAddr *from, int fromLen __attrib
     } else {
         /* try syscall since "from" was not given and PR_GetPeerName failed */
         /* a corner case */
-        struct sockaddr_in addr = {0}; /* assuming IPv4 */
+        struct sockaddr addr = {0};
 #if (defined(hpux))
         int addrlen;
 #else
@@ -315,23 +338,15 @@ connection_reset(Connection *conn, int ns, PRNetAddr *from, int fromLen __attrib
         addrlen = sizeof(addr);
 
         if ((conn->c_prfd == NULL) &&
-            (getpeername(conn->c_sd, (struct sockaddr *)&addr, &addrlen) == 0)) {
+            (getpeername(conn->c_sd, (struct sockaddr *)&addr, &addrlen) == 0))
+        {
             conn->cin_addr = (PRNetAddr *)slapi_ch_malloc(sizeof(PRNetAddr));
             memset(conn->cin_addr, 0, sizeof(PRNetAddr));
             PR_NetAddrFamily(conn->cin_addr) = AF_INET6;
             /* note: IPv4-mapped IPv6 addr does not work on Windows */
-            PR_ConvertIPv4AddrToIPv6(addr.sin_addr.s_addr, &(conn->cin_addr->ipv6.ip));
-            PRLDAP_SET_PORT(conn->cin_addr, addr.sin_port);
-
-            /* copy string equivalent of address into a buffer to use for
-             * logging since each call to inet_ntoa() returns a pointer to a
-             * single thread-specific buffer (which prevents us from calling
-             * inet_ntoa() twice in one call to slapi_log_access()).
-             */
-            str_ip = inet_ntoa(addr.sin_addr);
-            strncpy(buf_ip, str_ip, sizeof(buf_ip) - 1);
-            buf_ip[sizeof(buf_ip) - 1] = '\0';
-            str_ip = buf_ip;
+            PR_ConvertIPv4AddrToIPv6(((struct sockaddr_in *)&addr)->sin_addr.s_addr, &(conn->cin_addr->ipv6.ip));
+            PRLDAP_SET_PORT(conn->cin_addr, ((struct sockaddr_in *)&addr)->sin_port);
+            str_ip = get_ip_str(&addr, buf_ip);
         } else {
             str_ip = str_unknown;
         }
@@ -367,38 +382,27 @@ connection_reset(Connection *conn, int ns, PRNetAddr *from, int fromLen __attrib
     } else {
         /* try syscall since c_prfd == NULL */
         /* a corner case */
-        struct sockaddr_in destaddr = {0}; /* assuming IPv4 */
+        struct sockaddr destaddr = {0}; /* assuming IPv4 */
 #if (defined(hpux))
         int destaddrlen;
 #else
         socklen_t destaddrlen;
 #endif
-
         destaddrlen = sizeof(destaddr);
 
-        if ((getsockname(conn->c_sd, (struct sockaddr *)&destaddr, &destaddrlen) == 0)) {
+        if ((getsockname(conn->c_sd, &destaddr, &destaddrlen) == 0)) {
             conn->cin_destaddr = (PRNetAddr *)slapi_ch_malloc(sizeof(PRNetAddr));
             memset(conn->cin_destaddr, 0, sizeof(PRNetAddr));
             PR_NetAddrFamily(conn->cin_destaddr) = AF_INET6;
-            PRLDAP_SET_PORT(conn->cin_destaddr, destaddr.sin_port);
+            PRLDAP_SET_PORT(conn->cin_destaddr, ((struct sockaddr_in *)&destaddr)->sin_port);
             /* note: IPv4-mapped IPv6 addr does not work on Windows */
-            PR_ConvertIPv4AddrToIPv6(destaddr.sin_addr.s_addr, &(conn->cin_destaddr->ipv6.ip));
-
-            /* copy string equivalent of address into a buffer to use for
-             * logging since each call to inet_ntoa() returns a pointer to a
-             * single thread-specific buffer (which prevents us from calling
-             * inet_ntoa() twice in one call to slapi_log_access()).
-             */
-            str_destip = inet_ntoa(destaddr.sin_addr);
-            strncpy(buf_destip, str_destip, sizeof(buf_destip) - 1);
-            buf_destip[sizeof(buf_destip) - 1] = '\0';
-            str_destip = buf_destip;
+            PR_ConvertIPv4AddrToIPv6(((struct sockaddr_in *)&destaddr)->sin_addr.s_addr, &(conn->cin_destaddr->ipv6.ip));
+            str_destip = get_ip_str(&destaddr, buf_destip);
         } else {
             str_destip = str_unknown;
         }
     }
 
-
     if (!in_referral_mode) {
         /* create a sasl connection */
         ids_sasl_server_new(conn);
@@ -518,11 +522,11 @@ connection_need_new_password(const Connection *conn, const Operation *op, Slapi_
 static void
 connection_dispatch_operation(Connection *conn, Operation *op, Slapi_PBlock *pb)
 {
-    int minssf = config_get_minssf();
-    int minssf_exclude_rootdse = 0;
+    int32_t minssf = conn->c_minssf;
+    int32_t minssf_exclude_rootdse = conn->c_minssf_exclude_rootdse;
 #ifdef TCP_CORK
-    int enable_nagle = config_get_nagle();
-    int pop_cork = 0;
+    int32_t enable_nagle = conn->c_enable_nagle;
+    int32_t pop_cork = 0;
 #endif
 
     /* Set the connid and op_id to be used by internal op logging */
@@ -534,13 +538,11 @@ connection_dispatch_operation(Connection *conn, Operation *op, Slapi_PBlock *pb)
     /* Copy the Connection DN and SSF into the operation struct */
     op_copy_identity(conn, op);
 
-#if defined(USE_OPENLDAP)
     if (slapi_operation_is_flag_set(op, OP_FLAG_REPLICATED)) {
         /* If it is replicated op, ignore the maxbersize. */
         ber_len_t maxbersize = 0;
         ber_sockbuf_ctrl(conn->c_sb, LBER_SB_OPT_SET_MAX_INCOMING, &maxbersize);
     }
-#endif
 
     /* If the minimum SSF requirements are not met, only allow
      * bind and extended operations through.  The bind and extop
@@ -552,7 +554,6 @@ connection_dispatch_operation(Connection *conn, Operation *op, Slapi_PBlock *pb)
      * next step and check if the operation is against rootdse or not.
      * Once found it's not on rootdse, return LDAP_UNWILLING_TO_PERFORM there.
      */
-    minssf_exclude_rootdse = config_get_minssf_exclude_rootdse();
     if (!minssf_exclude_rootdse &&
         (conn->c_sasl_ssf < minssf) && (conn->c_ssl_ssf < minssf) &&
         (conn->c_local_ssf < minssf) && (op->o_tag != LDAP_REQ_BIND) &&
@@ -580,10 +581,10 @@ connection_dispatch_operation(Connection *conn, Operation *op, Slapi_PBlock *pb)
      * search. */
     if ((slapi_sdn_get_dn(&(op->o_sdn)) == NULL) &&
         /* anon access off and something other than BIND, EXTOP, UNBIND or ABANDON */
-        (((config_get_anon_access_switch() == SLAPD_ANON_ACCESS_OFF) && (op->o_tag != LDAP_REQ_BIND) &&
+        (((conn->c_anon_access == SLAPD_ANON_ACCESS_OFF) && (op->o_tag != LDAP_REQ_BIND) &&
           (op->o_tag != LDAP_REQ_EXTENDED) && (op->o_tag != LDAP_REQ_UNBIND) && (op->o_tag != LDAP_REQ_ABANDON)) ||
          /* root DSE access only and something other than BIND, EXTOP, UNBIND, ABANDON, or SEARCH */
-         ((config_get_anon_access_switch() == SLAPD_ANON_ACCESS_ROOTDSE) && (op->o_tag != LDAP_REQ_BIND) &&
+         ((conn->c_anon_access == SLAPD_ANON_ACCESS_ROOTDSE) && (op->o_tag != LDAP_REQ_BIND) &&
           (op->o_tag != LDAP_REQ_EXTENDED) && (op->o_tag != LDAP_REQ_UNBIND) &&
           (op->o_tag != LDAP_REQ_ABANDON) && (op->o_tag != LDAP_REQ_SEARCH)))) {
         slapi_log_access(LDAP_DEBUG_STATS,
@@ -781,7 +782,6 @@ struct Conn_private
     int use_buffer;                   /* if true, use the buffer - if false, ber_get_next reads directly from socket */
 };
 
-#if defined(USE_OPENLDAP)
 /* Copy up to bytes_to_read bytes from b into return_buffer.
  * Returns a count of bytes copied (always >= 0).
  */
@@ -835,7 +835,6 @@ openldap_read_function(Sockbuf_IO_Desc *sbiod, void *buf, ber_len_t len)
 done:
     return bytes_to_copy;
 }
-#endif
 
 int
 connection_new_private(Connection *conn)
@@ -936,7 +935,8 @@ connection_free_private_buffer(Connection *conn)
 #define CONN_DONE 3
 #define CONN_TIMEDOUT 4
 
-#define CONN_TURBO_TIMEOUT_INTERVAL 1000 /* milliseconds */
+#define CONN_TURBO_TIMEOUT_INTERVAL 100 /* milliseconds */
+#define CONN_TURBO_TIMEOUT_MAXIMUM 5 /* attempts * interval IE 2000ms with 400 * 5 */
 #define CONN_TURBO_CHECK_INTERVAL 5      /* seconds */
 #define CONN_TURBO_PERCENTILE 50         /* proportion of threads allowed to be in turbo mode */
 #define CONN_TURBO_HYSTERESIS 0          /* avoid flip flopping in and out of turbo mode */
@@ -988,20 +988,12 @@ connection_wait_for_new_work(Slapi_PBlock *pb, PRIntervalTime interval)
     return ret;
 }
 
-#ifdef USE_OPENLDAP
 #include "openldapber.h"
-#else
-#include "mozldap.h"
-#endif
 
 static ber_tag_t
 _ber_get_len(BerElement *ber, ber_len_t *lenp)
 {
-#ifdef USE_OPENLDAP
     OLBerElement *lber = (OLBerElement *)ber;
-#else
-    MozElement *lber = (MozElement *)ber;
-#endif
 
     if (NULL == lenp) {
         return LBER_DEFAULT;
@@ -1041,19 +1033,14 @@ get_next_from_buffer(void *buffer __attribute__((unused)), size_t buffer_size __
     ber_len_t bytes_scanned = 0;
 
     *lenp = 0;
-#if defined(USE_OPENLDAP)
     *tagp = ber_get_next(conn->c_sb, &bytes_scanned, ber);
-#else
-    *tagp = ber_get_next_buffer_ext(buffer, buffer_size, lenp, ber,
-                                    &bytes_scanned, conn->c_sb);
-#endif
     /* openldap ber_get_next doesn't return partial bytes_scanned if it hasn't
        read a whole pdu - so we have to check the errno for the
        "would block" condition meaning openldap needs more data to read */
     if ((LBER_OVERFLOW == *tagp || LBER_DEFAULT == *tagp) && 0 == bytes_scanned &&
         !SLAPD_SYSTEM_WOULD_BLOCK_ERROR(errno)) {
         if ((LBER_OVERFLOW == *tagp) || (errno == ERANGE)) {
-            ber_len_t maxbersize = config_get_maxbersize();
+            ber_len_t maxbersize = conn->c_maxbersize;
             ber_len_t tmplen = 0;
             (void)_ber_get_len(ber, &tmplen);
             /* openldap does not differentiate between length == 0
@@ -1080,15 +1067,8 @@ get_next_from_buffer(void *buffer __attribute__((unused)), size_t buffer_size __
             SLAPD_SYSTEM_WOULD_BLOCK_ERROR(errno)) {
             return -2; /* tells connection_read_operation we need to try again */
         }
-    } else {
-/* openldap_read_function will advance c_buffer_offset */
-#if !defined(USE_OPENLDAP)
-        /* success, or need to wait for more data */
-        /* if openldap could not read a whole pdu, bytes_scanned will be zero -
-              it does not return partial results */
-        conn->c_private->c_buffer_offset += bytes_scanned;
-#endif
-    }
+    } /* else, openldap_read_function will advance c_buffer_offset,
+         nothing to do (we had to previously with mozldap) */
     return 0;
 }
 
@@ -1141,7 +1121,7 @@ connection_read_operation(Connection *conn, Operation *op, ber_tag_t *tag, int *
 {
     ber_len_t len = 0;
     int ret = 0;
-    int waits_done = 0;
+    int32_t waits_done = 0;
     ber_int_t msgid;
     int new_operation = 1; /* Are we doing the first I/O read for a new operation ? */
     char *buffer = conn->c_private->c_buffer;
@@ -1176,7 +1156,7 @@ connection_read_operation(Connection *conn, Operation *op, ber_tag_t *tag, int *
     }
     /* If we still haven't seen a complete PDU, read from the network */
     while (*tag == LBER_DEFAULT) {
-        int ioblocktimeout_waits = config_get_ioblocktimeout() / CONN_TURBO_TIMEOUT_INTERVAL;
+        int32_t ioblocktimeout_waits = conn->c_ioblocktimeout / CONN_TURBO_TIMEOUT_INTERVAL;
         /* We should never get here with data remaining in the buffer */
         PR_ASSERT(!new_operation || !conn_buffered_data_avail_nolock(conn, &conn_closed));
         /* We make a non-blocking read call */
@@ -1211,7 +1191,9 @@ connection_read_operation(Connection *conn, Operation *op, ber_tag_t *tag, int *
                 pr_pd.fd = (PRFileDesc *)conn->c_prfd;
                 pr_pd.in_flags = PR_POLL_READ;
                 pr_pd.out_flags = 0;
+                PR_Lock(conn->c_pdumutex);
                 ret = PR_Poll(&pr_pd, 1, timeout);
+                PR_Unlock(conn->c_pdumutex);
                 waits_done++;
                 /* Did we time out ? */
                 if (0 == ret) {
@@ -1624,7 +1606,7 @@ connection_threadmain()
             g_decr_active_threadcnt();
             return;
         }
-        maxthreads = config_get_maxthreadsperconn();
+        maxthreads = conn->c_max_threads_per_conn;
         more_data = 0;
         ret = connection_read_operation(conn, op, &tag, &more_data);
         if ((ret == CONN_DONE) || (ret == CONN_TIMEDOUT)) {
@@ -1882,6 +1864,7 @@ connection_threadmain()
                         signal_listner();
                     }
                 } else if (1 == is_timedout) {
+                    /* covscan reports this code is unreachable  (2019/6/4) */
                     connection_make_readable_nolock(conn);
                     signal_listner();
                 }
@@ -2195,9 +2178,8 @@ connection_set_ssl_ssf(Connection *conn)
 static int
 is_ber_too_big(const Connection *conn, ber_len_t ber_len)
 {
-    ber_len_t maxbersize = config_get_maxbersize();
-    if (ber_len > maxbersize) {
-        log_ber_too_big_error(conn, ber_len, maxbersize);
+    if (ber_len > conn->c_maxbersize) {
+        log_ber_too_big_error(conn, ber_len, conn->c_maxbersize);
         return 1;
     }
     return 0;
@@ -2213,7 +2195,7 @@ static void
 log_ber_too_big_error(const Connection *conn, ber_len_t ber_len, ber_len_t maxbersize)
 {
     if (0 == maxbersize) {
-        maxbersize = config_get_maxbersize();
+        maxbersize = conn->c_maxbersize;
     }
     if (0 == ber_len) {
         slapi_log_err(SLAPI_LOG_ERR, "log_ber_too_big_error",
