@@ -393,7 +393,7 @@ int config_set_malloc_mxfast(const char *attrname, char *value, char *errorbuf,
 int config_set_malloc_trim_threshold(const char *attrname, char *value, char *errorbuf, int apply);
 int config_set_malloc_mmap_threshold(const char *attrname, char *value, char *errorbuf, int apply);
 #endif
-int config_set_maxdescriptors(const char *attrname, char *value, char *errorbuf, int apply);
+int32_t config_set_maxdescriptors(const char *attrname, char *value, char *errorbuf, int apply);
 int config_set_localuser(const char *attrname, char *value, char *errorbuf, int apply);
 
 int config_set_maxsimplepaged_per_conn(const char *attrname, char *value, char *errorbuf, int apply);
@@ -475,7 +475,7 @@ char *config_get_workingdir(void);
 char *config_get_encryptionalias(void);
 int32_t config_get_threadnumber(void);
 int config_get_maxthreadsperconn(void);
-int config_get_maxdescriptors(void);
+int64_t config_get_maxdescriptors(void);
 int config_get_reservedescriptors(void);
 int config_get_ioblocktimeout(void);
 int config_get_idletimeout(void);
@@ -701,6 +701,7 @@ int dse_read_file(struct dse *pdse, Slapi_PBlock *pb);
 int dse_bind(Slapi_PBlock *pb);
 int dse_unbind(Slapi_PBlock *pb);
 int dse_search(Slapi_PBlock *pb);
+int32_t dse_compare(Slapi_PBlock *pb);
 int dse_modify(Slapi_PBlock *pb);
 int dse_add(Slapi_PBlock *pb);
 int dse_delete(Slapi_PBlock *pb);
@@ -1449,9 +1450,7 @@ int connection_release_nolock(Connection *conn);
 int connection_release_nolock_ext(Connection *conn, int release_only);
 int connection_is_free(Connection *conn, int user_lock);
 int connection_is_active_nolock(Connection *conn);
-#if defined(USE_OPENLDAP)
 ber_slen_t openldap_read_function(Sockbuf_IO_Desc *sbiod, void *buf, ber_len_t len);
-#endif
 
 /*
  * saslbind.c
