@@ -30,11 +30,8 @@ var info = {
         "fonts",
         "images",
         "index.html",
-        "monitor.html",
-        "monitor.js",
         "replication.html",
         "replication.js",
-        "rhds-banner.html",
         "schema.html",
         "schema.js",
         "security.html",
