@@ -14,7 +14,7 @@ from lib389.changelog import Changelog5
 from lib389.utils import is_a_dn
 from lib389.replica import Replicas, BootstrapReplicationManager
 from lib389.tasks import CleanAllRUVTask, AbortCleanAllRUVTask
-
+from lib389._mapped_object import DSLdapObjects
 
 arg_to_attr = {
         # replica config
@@ -29,6 +29,7 @@ arg_to_attr = {
         'repl_backoff_max': 'nsds5replicabackoffmax',
         'repl_release_timeout': 'nsds5replicareleasetimeout',
         # Changelog
+        'cl_dir': 'nsslapd-changelogdir',
         'max_entries': 'nsslapd-changelogmaxentries',
         'max_age': 'nsslapd-changelogmaxage',
         'compact_interval': 'nsslapd-changelogcompactdb-interval',
@@ -69,7 +70,7 @@ arg_to_attr = {
 
 
 def get_agmt(inst, args, winsync=False):
-    agmt_name = args.AGMT_NAME[0]
+    agmt_name = get_agmt_name(args)
     replicas = Replicas(inst)
     replica = replicas.get(args.suffix)
     agmts = replica.get_agreements(winsync=winsync)
@@ -80,6 +81,14 @@ def get_agmt(inst, args, winsync=False):
     return agmt
 
 
+def get_agmt_name(args):
+    agmt_name = args.AGMT_NAME[0]
+    if agmt_name.startswith('"') and agmt_name.endswith('"'):
+        # Remove quotes from quoted value
+        agmt_name = agmt_name[1:-1]
+    return agmt_name
+
+
 def _args_to_attrs(args):
     attrs = {}
     for arg in vars(args):
@@ -116,6 +125,7 @@ def enable_replication(inst, basedn, log, args):
         'nsDS5ReplicaRoot': repl_root,
         'nsDS5Flags': repl_flag,
         'nsDS5ReplicaType': repl_type,
+        'nsDS5ReplicaId': '65535'
         }
 
     # Validate master settings
@@ -129,19 +139,19 @@ def enable_replication(inst, basedn, log, args):
         try:
             rid_num = int(rid)
         except ValueError:
-            raise ValueError("--rid expects a number between 1 and 65534")
+            raise ValueError("--replica-id expects a number between 1 and 65534")
 
         # Is it in range?
         if rid_num < 1 or rid_num > 65534:
             raise ValueError("--replica-id expects a number between 1 and 65534")
 
         # rid is good add it to the props
-        repl_properties['nsDS5ReplicaId'] = rid
+        repl_properties['nsDS5ReplicaId'] = args.replica_id
 
     # Bind DN or Bind DN Group?
     if args.bind_group_dn:
         repl_properties['nsDS5ReplicaBindDNGroup'] = args.bind_group_dn
-    elif args.bind_dn:
+    if args.bind_dn:
         repl_properties['nsDS5ReplicaBindDN'] = args.bind_dn
 
     # First create the changelog
@@ -161,7 +171,31 @@ def enable_replication(inst, basedn, log, args):
     except ldap.ALREADY_EXISTS:
         raise ValueError("Replication is already enabled for this suffix")
 
-    print("Replication successfully enabled for \"{}\"".format(repl_root))
+    # Create replication manager if password was provided
+    if args.bind_dn and args.bind_passwd:
+        cn_rdn = args.bind_dn.split(",", 1)[0]
+        cn_val = cn_rdn.split("=", 1)[1]
+        manager = BootstrapReplicationManager(inst, dn=args.bind_dn)
+        try:
+            manager.create(properties={
+                'cn': cn_val,
+                'userPassword': args.bind_passwd
+            })
+        except ldap.ALREADY_EXISTS:
+            # Already there, but could have different password.  Delete and recreate
+            manager.delete()
+            manager.create(properties={
+                'cn': cn_val,
+                'userPassword': args.bind_passwd
+            })
+        except ldap.NO_SUCH_OBJECT:
+            # Invalid Entry
+            raise ValueError("Failed to add replication manager because the base DN of the entry does not exist")
+        except ldap.LDAPError as e:
+            # Some other bad error
+            raise ValueError("Failed to create replication manager entry: " + str(e))
+
+    log.info("Replication successfully enabled for \"{}\"".format(repl_root))
 
 
 def disable_replication(inst, basedn, log, args):
@@ -171,7 +205,7 @@ def disable_replication(inst, basedn, log, args):
         replica.delete()
     except ldap.NO_SUCH_OBJECT:
         raise ValueError("Backend \"{}\" is not enabled for replication".format(args.suffix))
-    print("Replication disabled for \"{}\"".format(args.suffix))
+    log.info("Replication disabled for \"{}\"".format(args.suffix))
 
 
 def promote_replica(inst, basedn, log, args):
@@ -181,7 +215,7 @@ def promote_replica(inst, basedn, log, args):
 
     if role == 'master':
         newrole = ReplicaRole.MASTER
-        if args.rreplica_idid is None:
+        if args.replica_id is None:
             raise ValueError("You need to provide a replica ID (--replica-id) to promote replica to a master")
     elif role == 'hub':
         newrole = ReplicaRole.HUB
@@ -189,7 +223,7 @@ def promote_replica(inst, basedn, log, args):
         raise ValueError("Invalid role ({}), you must use either \"master\" or \"hub\"".format(role))
 
     replica.promote(newrole, binddn=args.bind_dn, binddn_group=args.bind_group_dn, rid=args.replica_id)
-    print("Successfully promoted replica to \"{}\"".format(role))
+    log.info("Successfully promoted replica to \"{}\"".format(role))
 
 
 def demote_replica(inst, basedn, log, args):
@@ -205,14 +239,52 @@ def demote_replica(inst, basedn, log, args):
         raise ValueError("Invalid role ({}), you must use either \"hub\" or \"consumer\"".format(role))
 
     replica.demote(newrole)
-    print("Successfully demoted replica to \"{}\"".format(role))
+    log.info("Successfully demoted replica to \"{}\"".format(role))
+
+
+def list_suffixes(inst, basedn, log, args):
+    suffixes = []
+    replicas = Replicas(inst).list()
+    for replica in replicas:
+        suffixes.append(replica.get_suffix())
+
+    if args.json:
+        log.info(json.dumps({"type": "list", "items": suffixes}))
+    else:
+        if len(suffixes) == 0:
+            log.info("There are no replicated suffixes")
+        else:
+            for suffix in suffixes:
+                log.info(suffix)
+
+
+def get_repl_status(inst, basedn, log, args):
+    replicas = Replicas(inst)
+    replica = replicas.get(args.suffix)
+    status = replica.status(binddn=args.bind_dn, bindpw=args.bind_passwd)
+    if args.json:
+        log.info(json.dumps({"type": "list", "items": status}))
+    else:
+        for agmt in status:
+            log.info(agmt)
+
+
+def get_repl_winsync_status(inst, basedn, log, args):
+    replicas = Replicas(inst)
+    replica = replicas.get(args.suffix)
+    status = replica.status(binddn=args.bind_dn, bindpw=args.bind_passwd, winsync=True)
+    if args.json:
+        log.info(json.dumps({"type": "list", "items": status}))
+    else:
+        for agmt in status:
+            log.info(agmt)
 
 
 def get_repl_config(inst, basedn, log, args):
     replicas = Replicas(inst)
     replica = replicas.get(args.suffix)
     if args and args.json:
-        print(replica.get_all_attrs_json())
+        log.info(replica.get_all_attrs_json())
     else:
         log.info(replica.display())
 
@@ -221,39 +293,46 @@ def set_repl_config(inst, basedn, log, args):
     replicas = Replicas(inst)
     replica = replicas.get(args.suffix)
     attrs = _args_to_attrs(args)
-    op_count = 0
+    did_something = False
 
     # Add supplier DNs
     if args.repl_add_bind_dn is not None:
-        if not is_a_dn(repl_add_bind_dn):
+        if not is_a_dn(args.repl_add_bind_dn):
             raise ValueError("The replica bind DN is not a valid DN")
         replica.add('nsds5ReplicaBindDN', args.repl_add_bind_dn)
-        op_count += 1
+        did_something = True
 
     # Remove supplier DNs
     if args.repl_del_bind_dn is not None:
         replica.remove('nsds5ReplicaBindDN', args.repl_del_bind_dn)
-        op_count += 1
+        did_something = True
 
     # Add referral
     if args.repl_add_ref is not None:
         replica.add('nsDS5ReplicaReferral', args.repl_add_ref)
-        op_count += 1
+        did_something = True
 
     # Remove referral
     if args.repl_del_ref is not None:
         replica.remove('nsDS5ReplicaReferral', args.repl_del_ref)
-        op_count += 1
+        did_something = True
 
     # Handle the rest of the changes that use mod_replace
-    modlist = []
+    replace_list = []
+
     for attr, value in attrs.items():
-        modlist.append((attr, value))
-    if len(modlist) > 0:
-        replica.replace_many(*modlist)
-    elif op_count == 0:
+        if value == "":
+            # Delete value
+            replica.remove_all(attr)
+            did_something = True
+        else:
+            replace_list.append((attr, value))
+    if len(replace_list) > 0:
+        replica.replace_many(*replace_list)
+    elif not did_something:
         raise ValueError("There are no changes to set in the replica")
-    print("Successfully updated replication configuration")
+
+    log.info("Successfully updated replication configuration")
 
 
 def create_cl(inst, basedn, log, args):
@@ -265,7 +344,7 @@ def create_cl(inst, basedn, log, args):
         })
     except ldap.ALREADY_EXISTS:
         raise ValueError("Changelog already exists")
-    print("Successfully created replication changelog")
+    log.info("Successfully created replication changelog")
 
 
 def delete_cl(inst, basedn, log, args):
@@ -274,26 +353,32 @@ def delete_cl(inst, basedn, log, args):
         cl.delete()
     except ldap.NO_SUCH_OBJECT:
         raise ValueError("There is no changelog to delete")
-    print("Successfully deleted replication changelog")
+    log.info("Successfully deleted replication changelog")
 
 
 def set_cl(inst, basedn, log, args):
     cl = Changelog5(inst)
     attrs = _args_to_attrs(args)
-    modlist = []
+    replace_list = []
+    did_something = False
     for attr, value in attrs.items():
-        modlist.append((attr, value))
-    if len(modlist) > 0:
-        cl.replace_many(*modlist)
-    else:
+        if value == "":
+            cl.remove_all(attr)
+            did_something = True
+        else:
+            replace_list.append((attr, value))
+    if len(replace_list) > 0:
+        cl.replace_many(*replace_list)
+    elif not did_something:
         raise ValueError("There are no changes to set for the replication changelog")
-    print("Successfully updated replication changelog")
+
+    log.info("Successfully updated replication changelog")
 
 
 def get_cl(inst, basedn, log, args):
     cl = Changelog5(inst)
     if args and args.json:
-        print(cl.get_all_attrs_json())
+        log.info(cl.get_all_attrs_json())
     else:
         log.info(cl.display())
 
@@ -311,6 +396,8 @@ def create_repl_manager(inst, basedn, log, args):
         if manager_cn.split("=", 1)[0].lower() != "cn":
             raise ValueError("Replication manager DN must use \"cn\" for the rdn attribute")
         manager_dn = manager_cn
+        manager_rdn = manager_dn.split(",", 1)[0]
+        manager_cn = manager_rdn.split("=", 1)[1]
     else:
         manager_dn = "cn={},cn=config".format(manager_cn)
 
@@ -326,7 +413,7 @@ def create_repl_manager(inst, basedn, log, args):
             if repl_manager_password_confirm == repl_manager_password:
                 break
             else:
-                print("Passwords do not match!\n")
+                log.info("Passwords do not match!\n")
                 repl_manager_password = ""
                 repl_manager_password_confirm = ""
 
@@ -336,19 +423,48 @@ def create_repl_manager(inst, basedn, log, args):
             'cn': manager_cn,
             'userPassword': repl_manager_password
         })
-        print ("Successfully created replication manager: " + manager_dn)
+        if args.suffix:
+            # Add supplier DN to config only if add succeeds
+            replicas = Replicas(inst)
+            replica = replicas.get(args.suffix)
+            try:
+                replica.add('nsds5ReplicaBindDN', manager_dn)
+            except ldap.TYPE_OR_VALUE_EXISTS:
+                pass
+        log.info("Successfully created replication manager: " + manager_dn)
     except ldap.ALREADY_EXISTS:
-        log.info("Replication Manager ({}) already exists".format(manager_dn))
+        log.info("Replication Manager ({}) already exists, recreating it...".format(manager_dn))
+        # Already there, but could have different password.  Delete and recreate
+        manager.delete()
+        manager.create(properties={
+            'cn': manager_cn,
+            'userPassword': repl_manager_password
+        })
+        if args.suffix:
+            # Add supplier DN to config only if add succeeds
+            replicas = Replicas(inst)
+            replica = replicas.get(args.suffix)
+            try:
+                replica.add('nsds5ReplicaBindDN', manager_dn)
+            except ldap.TYPE_OR_VALUE_EXISTS:
+                pass
+
+        log.info("Successfully created replication manager: " + manager_dn)
 
 
 def del_repl_manager(inst, basedn, log, args):
-    if is_a_dn(agmt.name):
+    if is_a_dn(args.name):
         manager_dn = args.name
     else:
         manager_dn = "cn={},cn=config".format(args.name)
     manager = BootstrapReplicationManager(inst, dn=manager_dn)
     manager.delete()
-    print("Successfully deleted replication manager: " + manager_dn)
+    if args.suffix:
+        # Add supplier DN to config
+        replicas = Replicas(inst)
+        replica = replicas.get(args.suffix)
+        replica.remove('nsds5ReplicaBindDN', manager_dn)
+    log.info("Successfully deleted replication manager: " + manager_dn)
 
 
 #
@@ -367,9 +483,9 @@ def list_agmts(inst, basedn, log, args):
             # Append decoded json object, because we are going to dump it later
             result['items'].append(json.loads(entry))
         else:
-            print(agmt.display())
+            log.info(agmt.display())
     if args.json:
-        print(json.dumps(result))
+        log.info(json.dumps(result))
 
 
 def add_agmt(inst, basedn, log, args):
@@ -394,9 +510,9 @@ def add_agmt(inst, basedn, log, args):
 
     # Required properties
     properties = {
-            'cn': args.AGMT_NAME[0],
+            'cn': get_agmt_name(args),
             'nsDS5ReplicaRoot': repl_root,
-            'description': args.AGMT_NAME[0],
+            'description': get_agmt_name(args),
             'nsDS5ReplicaHost': args.host,
             'nsDS5ReplicaPort': args.port,
             'nsDS5ReplicaBindMethod': bind_method,
@@ -429,7 +545,7 @@ def add_agmt(inst, basedn, log, args):
     except ldap.ALREADY_EXISTS:
         raise ValueError("A replication agreement with the same name already exists")
 
-    print("Successfully created replication agreement \"{}\"".format(args.AGMT_NAME[0]))
+    log.info("Successfully created replication agreement \"{}\"".format(get_agmt_name(args)))
     if args.init:
         init_agmt(inst, basedn, log, args)
 
@@ -437,25 +553,25 @@ def add_agmt(inst, basedn, log, args):
 def delete_agmt(inst, basedn, log, args):
     agmt = get_agmt(inst, args)
     agmt.delete()
-    print("Agreement has been successfully deleted")
+    log.info("Agreement has been successfully deleted")
 
 
 def enable_agmt(inst, basedn, log, args):
     agmt = get_agmt(inst, args)
     agmt.resume()
-    print("Agreement has been enabled")
+    log.info("Agreement has been enabled")
 
 
 def disable_agmt(inst, basedn, log, args):
     agmt = get_agmt(inst, args)
     agmt.pause()
-    print("Agreement has been disabled")
+    log.info("Agreement has been disabled")
 
 
 def init_agmt(inst, basedn, log, args):
     agmt = get_agmt(inst, args)
     agmt.begin_reinit()
-    print("Agreement initialization started...")
+    log.info("Agreement initialization started...")
 
 
 def check_init_agmt(inst, basedn, log, args):
@@ -469,30 +585,43 @@ def check_init_agmt(inst, basedn, log, args):
     elif error:
         status = "Agreement initialization failed."
     if args.json:
-        print(json.dumps(status))
+        log.info(json.dumps(status))
     else:
-        print(status)
+        log.info(status)
 
 
 def set_agmt(inst, basedn, log, args):
     agmt = get_agmt(inst, args)
     attrs = _args_to_attrs(args)
     modlist = []
+    did_something = False
     for attr, value in attrs.items():
-        modlist.append((attr, value))
+        if value == "":
+            # Delete value
+            agmt.remove_all(attr)
+            did_something = True
+        else:
+            if attr == 'nsds5replicatedattributelist' or attr == 'nsds5replicatedattributelisttotal':
+                frac_list = "(objectclass=*) $ EXCLUDE"
+                for frac_attr in value.split():
+                    frac_list += " " + frac_attr
+                value = frac_list
+            modlist.append((attr, value))
+
     if len(modlist) > 0:
         agmt.replace_many(*modlist)
-    else:
+    elif not did_something:
         raise ValueError("There are no changes to set in the agreement")
-    print("Successfully updated agreement")
+
+    log.info("Successfully updated agreement")
 
 
 def get_repl_agmt(inst, basedn, log, args):
     agmt = get_agmt(inst, args)
     if args.json:
-        print(agmt.get_all_attrs_json())
+        log.info(agmt.get_all_attrs_json())
     else:
-        print(agmt.display())
+        log.info(agmt.display())
 
 
 def poke_agmt(inst, basedn, log, args):
@@ -500,7 +629,7 @@ def poke_agmt(inst, basedn, log, args):
     agmt = get_agmt(inst, args)
     agmt.pause()
     agmt.resume()
-    print("Agreement has been poked")
+    log.info("Agreement has been poked")
 
 
 def get_agmt_status(inst, basedn, log, args):
@@ -510,7 +639,7 @@ def get_agmt_status(inst, basedn, log, args):
         while args.bind_passwd == "":
             args.bind_passwd = getpass("Enter password for \"{}\": ".format(args.bind_dn))
     status = agmt.status(use_json=args.json, binddn=args.bind_dn, bindpw=args.bind_passwd)
-    print(agmt, status)
+    log.info(status)
 
 
 #
@@ -529,9 +658,9 @@ def list_winsync_agmts(inst, basedn, log, args):
             # Append decoded json object, because we are going to dump it later
             result['items'].append(json.loads(entry))
         else:
-            print(agmt.display())
+            log.info(agmt.display())
     if args.json:
-        print(json.dumps(result))
+        log.info(json.dumps(result))
 
 
 def add_winsync_agmt(inst, basedn, log, args):
@@ -551,9 +680,9 @@ def add_winsync_agmt(inst, basedn, log, args):
 
     # Required properties
     properties = {
-            'cn': args.AGMT_NAME[0],
+            'cn': get_agmt_name(args),
             'nsDS5ReplicaRoot': args.suffix,
-            'description': args.AGMT_NAME[0],
+            'description': get_agmt_name(args),
             'nsDS5ReplicaHost': args.host,
             'nsDS5ReplicaPort': args.port,
             'nsDS5ReplicaTransportInfo': args.conn_protocol,
@@ -590,7 +719,7 @@ def add_winsync_agmt(inst, basedn, log, args):
     except ldap.ALREADY_EXISTS:
         raise ValueError("A replication agreement with the same name already exists")
 
-    print("Successfully created winsync replication agreement \"{}\"".format(args.AGMT_NAME[0]))
+    log.info("Successfully created winsync replication agreement \"{}\"".format(get_agmt_name(args)))
     if args.init:
         init_winsync_agmt(inst, basedn, log, args)
 
@@ -598,7 +727,7 @@ def add_winsync_agmt(inst, basedn, log, args):
 def delete_winsync_agmt(inst, basedn, log, args):
     agmt = get_agmt(inst, args, winsync=True)
     agmt.delete()
-    print("Agreement has been successfully deleted")
+    log.info("Agreement has been successfully deleted")
 
 
 def set_winsync_agmt(inst, basedn, log, args):
@@ -606,31 +735,38 @@ def set_winsync_agmt(inst, basedn, log, args):
 
     attrs = _args_to_attrs(args)
     modlist = []
-    for attr, value in attrs.items():
-        modlist.append((attr, value))
+    did_something = False
+    for attr, value in list(attrs.items()):
+        if value == "":
+            # Delete value
+            agmt.remove_all(attr)
+            did_something = True
+        else:
+            modlist.append((attr, value))
     if len(modlist) > 0:
         agmt.replace_many(*modlist)
-    else:
+    elif not did_something:
         raise ValueError("There are no changes to set in the agreement")
-    print("Successfully updated agreement")
+
+    log.info("Successfully updated agreement")
 
 
 def enable_winsync_agmt(inst, basedn, log, args):
     agmt = get_agmt(inst, args, winsync=True)
     agmt.resume()
-    print("Agreement has been enabled")
+    log.info("Agreement has been enabled")
 
 
 def disable_winsync_agmt(inst, basedn, log, args):
     agmt = get_agmt(inst, args, winsync=True)
     agmt.pause()
-    print("Agreement has been disabled")
+    log.info("Agreement has been disabled")
 
 
 def init_winsync_agmt(inst, basedn, log, args):
     agmt = get_agmt(inst, args, winsync=True)
     agmt.begin_reinit()
-    print("Agreement initialization started...")
+    log.info("Agreement initialization started...")
 
 
 def check_winsync_init_agmt(inst, basedn, log, args):
@@ -644,17 +780,17 @@ def check_winsync_init_agmt(inst, basedn, log, args):
     elif error:
         status = "Agreement initialization failed."
     if args.json:
-        print(json.dumps(status))
+        log.info(json.dumps(status))
     else:
-        print(status)
+        log.info(status)
 
 
 def get_winsync_agmt(inst, basedn, log, args):
     agmt = get_agmt(inst, args, winsync=True)
     if args.json:
-        print(agmt.get_all_attrs_json())
+        log.info(agmt.get_all_attrs_json())
     else:
-        print(agmt.display())
+        log.info(agmt.display())
 
 
 def poke_winsync_agmt(inst, basedn, log, args):
@@ -662,13 +798,13 @@ def poke_winsync_agmt(inst, basedn, log, args):
     agmt = get_agmt(inst, args, winsync=True)
     agmt.pause()
     agmt.resume()
-    print("Agreement has been poked")
+    log.info("Agreement has been poked")
 
 
 def get_winsync_agmt_status(inst, basedn, log, args):
     agmt = get_agmt(inst, args, winsync=True)
     status = agmt.status(winsync=True, use_json=args.json)
-    print(agmt, status)
+    log.info(status)
 
 
 #
@@ -678,20 +814,77 @@ def run_cleanallruv(inst, basedn, log, args):
     properties = {'replica-base-dn': args.suffix,
                   'replica-id': args.replica_id}
     if args.force_cleaning:
-        properties['replica-force-cleaning'] = args.force_cleaning
+        properties['replica-force-cleaning'] = 'yes'
     clean_task = CleanAllRUVTask(inst)
     clean_task.create(properties=properties)
+    rdn = clean_task.rdn
+    if args.json:
+        log.info(json.dumps(rdn))
+    else:
+        log.info('Created task ' + rdn)
+
+
+def list_cleanallruv(inst, basedn, log, args):
+    tasksobj = DSLdapObjects(inst)
+    tasksobj._basedn = "cn=cleanallruv, cn=tasks, cn=config"
+    tasksobj._scope = ldap.SCOPE_ONELEVEL
+    tasksobj._objectclasses = ['top']
+    tasks = tasksobj.list()
+    result = {"type": "list", "items": []}
+    tasks_found = False
+    for task in tasks:
+        tasks_found = True
+        if args.suffix is not None:
+            if args.suffix.lower() != task.get_attr_val_utf8_l('replica-base-dn'):
+                continue
+        if args.json:
+            entry = task.get_all_attrs_json()
+            # Append decoded json object, because we are going to dump it later
+            result['items'].append(json.loads(entry))
+        else:
+            log.info(task.display())
+    if args.json:
+        log.info(json.dumps(result))
+    else:
+        if not tasks_found:
+            log.info("No CleanAllRUV tasks found")
 
 
 def abort_cleanallruv(inst, basedn, log, args):
     properties = {'replica-base-dn': args.suffix,
                   'replica-id': args.replica_id}
     if args.certify:
-        properties['replica-certify-all'] = args.certify
+        properties['replica-certify-all'] = 'yes'
     clean_task = AbortCleanAllRUVTask(inst)
     clean_task.create(properties=properties)
 
 
+def list_abort_cleanallruv(inst, basedn, log, args):
+    tasksobj = DSLdapObjects(inst)
+    tasksobj._basedn = "cn=abort cleanallruv, cn=tasks, cn=config"
+    tasksobj._scope = ldap.SCOPE_ONELEVEL
+    tasksobj._objectclasses = ['top']
+    tasks = tasksobj.list()
+    result = {"type": "list", "items": []}
+    tasks_found = False
+    for task in tasks:
+        tasks_found = True
+        if args.suffix is not None:
+            if args.suffix.lower() != task.get_attr_val_utf8_l('replica-base-dn'):
+                continue
+        if args.json:
+            entry = task.get_all_attrs_json()
+            # Append decoded json object, because we are going to dump it later
+            result['items'].append(json.loads(entry))
+        else:
+            log.info(task.display())
+    if args.json:
+        log.info(json.dumps(result))
+    else:
+        if not tasks_found:
+            log.info("No CleanAllRUV abort tasks found")
+
+
 def create_parser(subparsers):
 
     ############################################
@@ -708,11 +901,27 @@ def create_parser(subparsers):
     repl_enable_parser.add_argument('--replica-id', help="The replication identifier for a \"master\".  Values range from 1 - 65534")
     repl_enable_parser.add_argument('--bind-group-dn', help="A group entry DN containing members that are \"bind/supplier\" DNs")
     repl_enable_parser.add_argument('--bind-dn', help="The Bind or Supplier DN that can make replication updates")
+    repl_enable_parser.add_argument('--bind-passwd', help="Password for replication manager(--bind-dn).  This will create the manager entry if a value is set")
 
     repl_disable_parser = repl_subcommands.add_parser('disable', help='Disable replication for a suffix')
     repl_disable_parser.set_defaults(func=disable_replication)
     repl_disable_parser.add_argument('--suffix', required=True, help='The DN of the suffix to have replication disabled')
 
+    repl_list_parser = repl_subcommands.add_parser('list', help='List all the replicated suffixes')
+    repl_list_parser.set_defaults(func=list_suffixes)
+
+    repl_status_parser = repl_subcommands.add_parser('status', help='Get the current status of all the replication agreements')
+    repl_status_parser.set_defaults(func=get_repl_status)
+    repl_status_parser.add_argument('--suffix', required=True, help="The DN of the replication suffix")
+    repl_status_parser.add_argument('--bind-dn', help="The DN to use to authenticate to the consumer")
+    repl_status_parser.add_argument('--bind-passwd', help="The password for the bind DN")
+
+    repl_winsync_status_parser = repl_subcommands.add_parser('winsync-status', help='Get the current status of all the replication agreements')
+    repl_winsync_status_parser.set_defaults(func=get_repl_winsync_status)
+    repl_winsync_status_parser.add_argument('--suffix', required=True, help="The DN of the replication suffix")
+    repl_winsync_status_parser.add_argument('--bind-dn', help="The DN to use to authenticate to the consumer")
+    repl_winsync_status_parser.add_argument('--bind-passwd', help="The password for the bind DN")
+
     repl_promote_parser = repl_subcommands.add_parser('promote', help='Promte replica to a Hub or Master')
     repl_promote_parser.set_defaults(func=promote_replica)
     repl_promote_parser.add_argument('--suffix', required=True, help="The DN of the replication suffix to promote")
@@ -723,12 +932,18 @@ def create_parser(subparsers):
 
     repl_add_manager_parser = repl_subcommands.add_parser('create-manager', help='Create a replication manager entry')
     repl_add_manager_parser.set_defaults(func=create_repl_manager)
-    repl_add_manager_parser.add_argument('--name', help="The NAME of the new replication manager entry under cn=config:  \"cn=NAME,cn=config\"")
+    repl_add_manager_parser.add_argument('--name', help="The NAME of the new replication manager entry.  For example, " +
+                                                        "if the NAME is \"replication manager\" then the new manager " +
+                                                        "entry's DN would be \"cn=replication manager,cn=config\".")
     repl_add_manager_parser.add_argument('--passwd', help="Password for replication manager.  If not provided, you will be prompted for the password")
+    repl_add_manager_parser.add_argument('--suffix', help='The DN of the replication suffix whose replication ' +
+                                                          'configuration you want to add this new manager to (OPTIONAL)')
 
     repl_del_manager_parser = repl_subcommands.add_parser('delete-manager', help='Delete a replication manager entry')
     repl_del_manager_parser.set_defaults(func=del_repl_manager)
     repl_del_manager_parser.add_argument('--name', help="The NAME of the replication manager entry under cn=config:  \"cn=NAME,cn=config\"")
+    repl_del_manager_parser.add_argument('--suffix', help='The DN of the replication suffix whose replication ' +
+                                                          'configuration you want to remove this manager from (OPTIONAL)')
 
     repl_demote_parser = repl_subcommands.add_parser('demote', help='Demote replica to a Hub or Consumer')
     repl_demote_parser.set_defaults(func=demote_replica)
@@ -745,16 +960,15 @@ def create_parser(subparsers):
     repl_delete_cl = repl_subcommands.add_parser('delete-changelog', help='Delete the replication changelog.  This will invalidate any existing replication agreements')
     repl_delete_cl.set_defaults(func=delete_cl)
 
-    repl_set_cl = repl_subcommands.add_parser('set-changelog', help='Delete the replication changelog.  This will invalidate any existing replication agreements')
+    repl_set_cl = repl_subcommands.add_parser('set-changelog', help='Set replication changelog attributes.')
     repl_set_cl.set_defaults(func=set_cl)
+    repl_set_cl.add_argument('--cl-dir', help="The replication changelog location on the filesystem")
     repl_set_cl.add_argument('--max-entries', help="The maximum number of entries to get in the replication changelog")
     repl_set_cl.add_argument('--max-age', help="The maximum age of a replication changelog entry")
     repl_set_cl.add_argument('--compact-interval', help="The replication changelog compaction interval")
     repl_set_cl.add_argument('--trim-interval', help="The interval to check if the replication changelog can be trimmed")
-    repl_set_cl.add_argument('--encrypt-algo', help="The encryption algorithm used to encrypt the replication changelog content.  Requires that TLS is enabled in the server")
-    repl_set_cl.add_argument('--encrypt-key', help="The symmetric key for the replication changelog encryption")
 
-    repl_get_cl = repl_subcommands.add_parser('get-changelog', help='Delete the replication changelog.  This will invalidate any existing replication agreements')
+    repl_get_cl = repl_subcommands.add_parser('get-changelog', help='Display replication changelog attributes.')
     repl_get_cl.set_defaults(func=get_cl)
 
     repl_set_parser = repl_subcommands.add_parser('set', help='Set an attribute in the replication configuration')
@@ -829,7 +1043,7 @@ def create_parser(subparsers):
     agmt_status_parser.set_defaults(func=get_agmt_status)
     agmt_status_parser.add_argument('AGMT_NAME', nargs=1, help='The name of the replication agreement')
     agmt_status_parser.add_argument('--suffix', required=True, help="The DN of the replication suffix")
-    agmt_status_parser.add_argument('--bind-dn', help="Set the DN to bind to the consumer")
+    agmt_status_parser.add_argument('--bind-dn', help="The DN to use to authenticate to the consumer")
     agmt_status_parser.add_argument('--bind-passwd', help="The password for the bind DN")
 
     # Delete
@@ -1024,7 +1238,7 @@ def create_parser(subparsers):
     # Replication Tasks (cleanalruv)
     ############################################
 
-    tasks_parser = subparsers.add_parser('repl-tasks', help='Manage local (user/subtree) password policies')
+    tasks_parser = subparsers.add_parser('repl-tasks', help='Manage replication tasks')
     task_subcommands = tasks_parser.add_subparsers(help='Replication Tasks')
 
     # Cleanallruv
@@ -1035,12 +1249,19 @@ def create_parser(subparsers):
     task_cleanallruv.add_argument('--force-cleaning', action='store_true', default=False,
                                   help="Ignore errors and do a best attempt to clean all the replicas")
 
+    task_cleanallruv_list = task_subcommands.add_parser('list-cleanruv-tasks', help='List all the running CleanAllRUV tasks')
+    task_cleanallruv_list.set_defaults(func=list_cleanallruv)
+    task_cleanallruv_list.add_argument('--suffix', help="List only tasks from for suffix")
+
     # Abort cleanallruv
-    task_abort_cleanallruv = task_subcommands.add_parser('abort-cleanallruv', help='Set an attribute in the replication winsync agreement')
+    task_abort_cleanallruv = task_subcommands.add_parser('abort-cleanallruv', help='Abort cleanallruv tasks')
     task_abort_cleanallruv.set_defaults(func=abort_cleanallruv)
     task_abort_cleanallruv.add_argument('--suffix', required=True, help="The Directory Server suffix")
     task_abort_cleanallruv.add_argument('--replica-id', required=True, help="The replica ID of the cleaning task to abort")
     task_abort_cleanallruv.add_argument('--certify', action='store_true', default=False,
                                         help="Enforce that the abort task completed on all replicas")
 
+    task_abort_cleanallruv_list = task_subcommands.add_parser('list-abortruv-tasks', help='List all the running CleanAllRUV abort Tasks')
+    task_abort_cleanallruv_list.set_defaults(func=list_abort_cleanallruv)
+    task_abort_cleanallruv_list.add_argument('--suffix', help="List only tasks from for suffix")
 
