@@ -1,5 +1,6 @@
 # --- BEGIN COPYRIGHT BLOCK ---
 # Copyright (C) 2015 Red Hat, Inc.
+# Copyright (C) 2019 William Brown <william@blackhats.net.au>
 # All rights reserved.
 #
 # License: GPL (version 3 or any later version).
@@ -32,8 +33,11 @@ import socket
 import time
 import sys
 import filecmp
+import pwd
 import six
 import shlex
+import operator
+import subprocess
 from socket import getfqdn
 from ldapurl import LDAPUrl
 from contextlib import closing
@@ -43,7 +47,7 @@ from lib389.paths import Paths
 from lib389.dseldif import DSEldif
 from lib389._constants import (
         DEFAULT_USER, VALGRIND_WRAPPER, DN_CONFIG, CFGSUFFIX, LOCALHOST,
-        ReplicaRole, CONSUMER_REPLICAID
+        ReplicaRole, CONSUMER_REPLICAID, SENSITIVE_ATTRS
     )
 from lib389.properties import (
         SER_HOST, SER_USER_ID, SER_GROUP_ID, SER_STRICT_HOSTNAME_CHECKING, SER_PORT,
@@ -53,6 +57,8 @@ from lib389.properties import (
 
 MAJOR, MINOR, _, _, _ = sys.version_info
 
+DEBUGGING = os.getenv('DEBUGGING', default=False)
+
 log = logging.getLogger(__name__)
 
 #
@@ -169,6 +175,130 @@ _chars = {
 # Utilities
 #
 
+def selinux_present():
+    """
+    Determine if selinux libraries are on a system, and if so, if we are in
+    a state to consume them (enabled, disabled).
+
+    :returns: bool
+    """
+    status = False
+
+    try:
+        import selinux
+        if selinux.is_selinux_enabled():
+            # We have selinux, continue.
+            status = True
+        else:
+            # We have the module, but it's disabled.
+            log.error('selinux is disabled, will not relabel ports or files.' )
+    except ImportError:
+        # No python module, so who knows what state we are in.
+        log.error('selinux python module not found, will not relabel files.' )
+
+    try:
+        if status:
+            # Only if we know it's enabled, check if we can manage ports too.
+            import sepolicy
+    except ImportError:
+        log.error('sepolicy python module not found, will not relabel ports.' )
+
+    return status
+
+
+def selinux_restorecon(path):
+    """
+    Relabel a filesystem rooted at path.
+
+    :param path: The filesystem path to recursively relabel
+    :type path: str:
+    """
+
+    try:
+        import selinux
+    except ImportError:
+        log.debug('selinux python module not found, skipping relabel path %s' % path)
+        return
+
+    if not selinux.is_selinux_enabled():
+        log.debug('selinux is disabled, skipping relabel path %s' % path)
+        return
+
+    try:
+        selinux.restorecon(path, recursive=True)
+    except:
+        log.debug("Failed to run restorecon on: " + path)
+
+
+def selinux_label_port(port, remove_label=False):
+    """
+    Either set or remove an SELinux label(ldap_port_t) for a TCP port
+
+    :param port: The TCP port to be labelled
+    :type port: str
+    :param remove_label: Set True if the port label should be removed
+    :type remove_label: boolean
+    :raises: ValueError: Error message
+    """
+    try:
+        import selinux
+    except ImportError:
+        log.debug('selinux python module not found, skipping port labeling.')
+        return
+
+    try:
+        import sepolicy
+    except ImportError:
+        log.debug('sepolicy python module not found, skipping port labeling.')
+        return
+
+    if not selinux.is_selinux_enabled():
+        log.debug('selinux is disabled, skipping port relabel')
+        return
+
+    # We only label ports that ARE NOT in the default policy that comes with
+    # a RH based system.
+    selinux_default_ports = [389, 636, 3268, 3269, 7389]
+    if port in selinux_default_ports:
+        log.debug('port %s already in %s, skipping port relabel' % (port, selinux_default_ports))
+        return
+
+    label_set = False
+    label_ex = None
+
+    policies = [p for p in sepolicy.info(sepolicy.PORT)
+                if p['protocol'] == 'tcp'
+                if port in range(p['low'], p['high'] + 1)
+                if p['type'] not in ['unreserved_port_t', 'reserved_port_t', 'ephemeral_port_t']]
+
+    for policy in policies:
+        if "ldap_port_t" == policy['type']:
+            label_set = True  # Port already has our label
+            if policy['low'] != policy['high']:
+                # We have a range
+                if port in range(policy['low'], policy['high'] + 1):
+                    # The port is within the range, just return
+                    return
+            break
+        elif not remove_label:
+            # Port belongs to someone else (bad)
+            # This is only an issue during setting a label, not removing a label
+            raise ValueError("Port {} was already labelled with: ({})  Please choose a different port number".format(port, policy['type']))
+
+    if (remove_label and label_set) or (not remove_label and not label_set):
+        for i in range(5):
+
+            try:
+                subprocess.check_call(["semanage", "port",
+                                       "-d" if remove_label else "-a",
+                                       "-t", "ldap_port_t",
+                                       "-p", "tcp", str(port)])
+                return
+            except (OSError, subprocess.CalledProcessError) as e:
+                label_ex = e
+                time.sleep(3)
+        raise ValueError("Failed to mangle port label: " + str(label_ex))
+
 
 def is_a_dn(dn, allow_anon=True):
     """Returns True if the given string is a DN, False otherwise."""
@@ -188,6 +318,39 @@ def is_a_dn(dn, allow_anon=True):
     return False
 
 
+def is_dn_parent(parent_dn, child_dn, ):
+    """ check if child_dn is a really a child of parent_dn
+    :return True - if child directly under parent, otherwise False
+    """
+    parent_dn = parent_dn.lower()
+    child_dn = child_dn.lower()
+
+    # Do some basic validation first
+    if not ldap.dn.is_dn(parent_dn) or not ldap.dn.is_dn(child_dn):
+        return False
+    if parent_dn == child_dn:
+        return False
+
+    # Get the DN comps and length
+    parent_dn_comps = ldap.dn.str2dn(parent_dn)
+    child_dn_comps = ldap.dn.str2dn(child_dn)
+    parent_comp_len = len(parent_dn_comps)
+    child_comp_len = len(child_dn_comps)
+
+    # Do a little more validation
+    if child_comp_len <= parent_comp_len or (child_comp_len - parent_comp_len) != 1:
+        return False
+
+    # Okay, finally comparing the base DN Comps to see if they match
+    for i, e in reversed(list(enumerate(parent_dn_comps))):
+        child_idx = i + (child_comp_len - parent_comp_len)
+        if child_dn_comps[child_idx] != e:
+            return False
+
+    # If we got here then child is a direct decendent of parent
+    return True
+
+
 def normalizeDN(dn, usespace=False):
     # not great, but will do until we use a newer version of python-ldap
     # that has DN utilities
@@ -796,7 +959,7 @@ def formatInfData(args):
     content = ("[General]" "\n")
     content += ("FullMachineName= %s\n" % args[SER_HOST])
     content += ("SuiteSpotUserID= %s\n" % args[SER_USER_ID])
-    content += ("nSuiteSpotGroup= %s\n" % args[SER_GROUP_ID])
+    content += ("SuiteSpotGroup= %s\n" % args[SER_GROUP_ID])
     content += ("StrictHostCheck= %s\n" % args[SER_STRICT_HOSTNAME_CHECKING])
 
     if args.get('have_admin'):
@@ -893,14 +1056,33 @@ def get_ds_version():
     return p.version
 
 
-def ds_is_older(ver):
-    """Return True if current version of ns-slapd is older than provided
-    version"""
-    return get_ds_version() < ver
+def ds_is_related(relation, *ver):
+    """
+    Return a result of a comparison between the current version of ns-slapd and a provided version.
+    """
+    ops = {'older': operator.lt,
+           'newer': operator.ge}
+    ds_ver = get_ds_version()
+    if len(ver) > 1:
+        for cmp_ver in ver:
+            if cmp_ver.startswith(ds_ver[:3]):
+                return ops[relation](ds_ver,cmp_ver)
+    else:
+        return ops[relation](ds_ver, ver[0])
 
 
-def ds_is_newer(ver):
-    return get_ds_version() >= ver
+def ds_is_older(*ver):
+    """
+    Return True if the current version of ns-slapd is older than a provided version
+    """
+    return ds_is_related('older', *ver)
+
+
+def ds_is_newer(*ver):
+    """
+    Return True if the current version of ns-slapd is newer than a provided version
+    """
+    return ds_is_related('newer', *ver)
 
 
 def getDateTime():
@@ -922,13 +1104,13 @@ def socket_check_open(host, port):
 
 
 def ensure_bytes(val):
-    if val != None and type(val) != bytes:
+    if val is not None and type(val) != bytes:
         return val.encode()
     return val
 
 
 def ensure_str(val):
-    if val != None and type(val) != str:
+    if val is not None and type(val) != str:
         try:
             result = val.decode('utf-8')
         except UnicodeDecodeError:
@@ -1025,3 +1207,65 @@ def get_ldapurl_from_serverid(instance):
     else:
         # Use LDAP
         return ("ldap://{}:{}".format(host, port), None)
+
+
+def get_instance_list(prefix=None):
+    # List all server instances
+    conf_dir = (prefix or "") + "/etc/dirsrv/"
+    insts = []
+    try:
+        for inst in os.listdir(conf_dir):
+            if inst.startswith('slapd-') and not inst.endswith('.removed'):
+                insts.append(inst)
+    except OSError as e:
+        log.error("Failed to check directory: {} - {}".format(conf_dir, str(e)))
+    insts.sort()
+    return insts
+
+
+def get_user_is_ds_owner():
+    # Check if we have permission to administer the DS instance. This is required
+    # for some tasks such as installing, killing, or editing configs for the
+    # instance.
+    cur_uid = os.getuid()
+    if cur_uid == 0:
+        # We are root, we have permission
+        return True
+    cur_username = pwd.getpwuid(cur_uid)[0]
+    p = Paths()
+    if cur_username == p.user:
+        # We are the same user, all good
+        return True
+    return False
+
+
+def get_user_is_root():
+    cur_uid = os.getuid()
+    if cur_uid == 0:
+        # We are root, we have permission
+        return True
+    return False
+
+
+def basedn_to_ldap_dns_uri(basedn):
+    # ldap:///dc%3Dexample%2Cdc%3Dcom
+    return "ldaps:///" + basedn.replace("=", "%3D").replace(",", "%2C")
+
+
+def display_log_value(attr, value, hide_sensitive=True):
+    # Mask all the sensitive attribute values
+    if DEBUGGING or not hide_sensitive:
+        return value
+    else:
+        if attr.lower() in SENSITIVE_ATTRS:
+            if type(value) in (list, tuple):
+                return list(map(lambda _: '********', value))
+            else:
+                return '********'
+        else:
+            return value
+
+
+def display_log_data(data, hide_sensitive=True):
+    # Take a dict and mask all the sensitive data
+    return {a: display_log_value(a, v, hide_sensitive) for a, v in data.items()}
